/* **************************************************** teo2gdk-pixbuf.h *** *
 * TEOGdkPixbufȤѴؿ إåե
 *
 * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <05/06/27 17:23:27 sugaya>
 * ************************************************************************* */
#ifndef __TEO2GDK_PIXBUF_H__
#define __TEO2GDK_PIXBUF_H__

GdkPixbuf*	Teo2GdkPixbuf_new_from_teoimage (TEOIMAGE	*img,
						 gboolean	normalize);

TEOIMAGE*	Teo2GdkPixbuf_new_from_pixbuf 	(GdkPixbuf	*src, 
						 gboolean	remove_alpha);

#endif /* __TEO2GDK_PIXBUF_H__ */

/* ********************************************* End of gdk2gdk-pixbuf.h *** */
